@@ -52,6 +52,7 @@ from .utils import (
     make_path_out,
     mynormpath,
     myparent,
+    myrelpath,
     string_to_list,
     translate,
     translate_back,
@@ -360,9 +361,17 @@ class InputNotFoundError(Exception):
 
 # A history used to avoid amending the same information twice.
 # This effectively reduces the amount of amend API calls.
-AMEND_HISTORY = {
-    "step_i": None,
-}
+AMEND_HISTORY = {}
+
+
+def _drop_amend_history():
+    AMEND_HISTORY["inp"] = set()
+    AMEND_HISTORY["env"] = set()
+    AMEND_HISTORY["out"] = set()
+    AMEND_HISTORY["vol"] = set()
+
+
+_drop_amend_history()
 
 
 def amend(
@@ -421,15 +430,6 @@ def amend(
         tr_out_paths = {translate(subs(out_path)) for out_path in out_paths}
         tr_vol_paths = {translate(subs(vol_path)) for vol_path in vol_paths}
 
-    # Clear the history if the worker started a new step.
-    step_i = _get_step_i()
-    if step_i != AMEND_HISTORY["step_i"]:
-        AMEND_HISTORY["step_i"] = step_i
-        AMEND_HISTORY["inp"] = set()
-        AMEND_HISTORY["env"] = set()
-        AMEND_HISTORY["out"] = set()
-        AMEND_HISTORY["vol"] = set()
-
     # Filter out previously amended information
     tr_inp_paths.difference_update(AMEND_HISTORY["inp"])
     env_vars.difference_update(AMEND_HISTORY["env"])
@@ -445,6 +445,7 @@ def amend(
         return
 
     # Finally, amend for real.
+    step_i = _get_step_i()
     amend_result = RPC_CLIENT.call.amend(
         step_i,
         tr_inp_paths,
@@ -1066,6 +1067,7 @@ def loadns(
     paths_variables
         paths of Python, JSON, TOML or YAML files containing variable definitions.
         They are loaded in the given order, so later variable definitions may overrule earlier ones.
+        Environment variables in path names are substituted.
     dir_out
         This is used to translate paths defined in the variables files
         (relative to parent of the variable file)
@@ -1080,8 +1082,13 @@ def loadns(
     variables
         A namespace with the variables.
     """
+    # Process arguments
     if dir_out is None:
         dir_out = Path.cwd()
+    with subs_env_vars() as subs:
+        paths_variables = [subs(path_var) for path_var in paths_variables]
+
+    # Build a dictionary of variables
     variables = {}
     for path_var in paths_variables:
         path_var = Path(path_var)
@@ -1104,13 +1111,17 @@ def loadns(
                 finally:
                     sys.path.remove(dir_py)
             for name, value in current.items():
+                if name.startswith("_"):
+                    continue
                 if isinstance(value, Path):
-                    value = value.relpath(dir_out)
+                    value = myrelpath(value, dir_out)
                 variables[name] = value
         else:
             raise ValueError(f"unsupported variable file format: {path_var}")
     if do_amend:
         amend(inp=paths_variables)
+
+    # Return as a namespace
     return argparse.Namespace(**variables)
 
 
@@ -1207,7 +1218,7 @@ def render_jinja(
 
 
 @contextlib.contextmanager
-def subs_env_vars() -> Iterator[Callable[[str | None], str | None]]:
+def subs_env_vars() -> Iterator[Callable[[str | None], Path | None]]:
     """A context manager for substituting environment variables and tracking the used variables.
 
     The context manager yields a function, `subs`, which takes a string with variables and
